/*
 * Copyright (c) 2011-2014, ScalaFX Project
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the ScalaFX Project nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE SCALAFX PROJECT OR ITS CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package scalafx.scene.input

import javafx.scene.{input => jfxsi}

import scala.language.implicitConversions
import scalafx.delegate.SFXDelegate

object KeyCodeCombination {
  implicit def sfxKeyCodeCombination2jfx(kcc: KeyCodeCombination): jfxsi.KeyCodeCombination = if (kcc != null) kcc.delegate else null
}

class KeyCodeCombination(override val delegate: jfxsi.KeyCodeCombination) extends KeyCombination(delegate) with SFXDelegate[jfxsi.KeyCodeCombination] {

  /**
   * Constructs a KeyCodeCombination for the specified main key and with the specified list of modifiers.
   */
  def this(code: jfxsi.KeyCode, modifiers: jfxsi.KeyCombination.Modifier*) = this(new jfxsi.KeyCodeCombination(code, modifiers: _*))

  /**
   * Constructs a KeyCodeCombination for the specified main key and with an explicit specification of all modifier keys.
   */
  def this(code: jfxsi.KeyCode, shift: jfxsi.KeyCombination.ModifierValue, control: jfxsi.KeyCombination.ModifierValue, alt: jfxsi.KeyCombination.ModifierValue, meta: jfxsi.KeyCombination.ModifierValue, shortcut: jfxsi.KeyCombination.ModifierValue) =
    this(new jfxsi.KeyCodeCombination(code, shift, control, alt, meta, shortcut))

  /**
   * Gets the key code associated with this key combination.
   */
  def code = delegate.getCode

}